/*
* bluebreeze theme for drupal
* ---------------------------
*
* created by Franz Heinzmann (frando)
* contact: frando at xcite-online dot de
*
* please report bugs not via e-mail but use the drupal.org bug tracker on
* http://drupal.org/project/bluebreeze
*
* inspired by the zen theme and the garland theme
*
* uses the .tpl.php-files of the zen theme with some small modifications
* and a modified "One True Layout" (see layout.css for details)
*
* the icons are created by Stefan Nagetaal, lullabot, Everaldo and Franz Heinzmann
* and are all available under the terms of the GPL
*
* licensed under the GPL.
*/

/* import the "One True Layout" */

@import "layout-rtl.css";

/* some common styles */

html, body, table th, table td {
  font-family: Verdana, sans-serif;
  font-size: 9pt;
  color: #393939;
  line-height: 1.7em;
  direction: rtl;
}

h1, h2, h3, h4, h5, h6 {
  margin: 0;
  padding: 0;
  font-weight: normal;
  direction: rtl; /* not sure needed*/
}

h1 {
  font-size: 170%;
  margin-bottom: .5em;
  padding-bottom: .35em;
  border-bottom: 1px solid #BFC4CF;
}

h2 {
  font-size: 160%;
}

h3 {
  font-size: 140%;
  font-weight: bold;
  color: #505050;
}

h4 {
  font-size: 140%;
}

h5 {
  font-size: 130%;
}

h6 {
  font-size: 120%;
}

/* links */

a:link, a:visited {
  color: #5294c1;
  text-decoration: none;
}

a:hover {
  color: #4c89bb;
  border-bottom: 1px solid #5294c1;
}

a:active, a.active {
  color: #778899;
}

/* some more items */

img, a img {
  border: none;
}

hr {
  margin: 0;
  padding: 0;
  border: none;
  height: 1px;
  background: #5294c1;
}

/* lists, menu */

ul, ul.menu, .item-list ul {
  margin: 0 .5em .5em 0; /* JCss.Old margin: 0 0 .5em 0 */
  padding: 0 0.5em 0 0; /* JCss.Old padding: 0 0 0 0.5em */
}

ul li, ul.menu li, .item-list ul li {
  margin: 0 1em 0 0; /* JCss.Old margin: 0 0 0 1em */
  padding: 0;
  direction: rtl; /* 2 line not sure needed */
  text-align: right;
  list-style: circle url(images/menu-leaf.gif);
}

ul li.expanded, ul.menu li.expanded, .item-list ul li.expanded {
  list-style: disc url(images/menu-expanded.gif);
}

ul li.collapsed, ul.menu li.collapsed, .item-list ul li.collapsed {
  list-style: square url(images/menu-collapsed-rtl.gif);
}

ul.menu li ul li {
  font-size: 95%;
}

ul.menu li ul li ul li {
  line-height: 1.6em;
}

/***********************
*   layout styling
***********************/

body, #page, #front, #second {
  padding: 0;
  margin: 0;
  background-color: #FDFEFF;
}

#container {
  background-color: #F3F7FB;
}

#main {
  background-color: #FDFEFF;
  padding: 10px 20px 20px 20px; /* JCss.Old padding: 10px 20px 20px 20px */
}

.withleft #main {
  border-right: 1px solid #DDE3ED; /* JCss.Old left JCSS_TMP_VALUE: 1px solid #DDE3ED */
}

.withright #main {
  border-left: 1px solid #DDE3ED; /* JCss.Old right right: 1px solid #DDE3ED */
}

/* header */

#header {
  height: 91px;
  background: url(images/bg-header.gif) repeat-x;
  padding: 0;
  margin: 8px 0 0 0; /* JCss.Old margin: 8px 0 0 0 */
}

#logo-title {
  position: relative;
  overflow: visible;
  float: right; /* JCss.Old float: left; */
  height: 91px;
  padding-right: 10px; /* JCss.Old left JCSS_TMP_VALUE: 10px */
  z-index: 1;

}

#header #site-name, #header #site-slogan {
  position: relative;
  padding: 0;
  margin: 0;
  right: 100px;  /* JCss.Old left JCSS_TMP_VALUE: 100px */
  top: 43px;
  padding-right: 10px; /* JCss.Old left JCSS_TMP_VALUE: 10px */
  border: 0;
}

#header #site-name a, #header #site-name a:visited, #header #site-name a:hover {
  font-family: Arial, Helvetica, sans-serif;
  font-size: 25px;
  color: #F8FEFF;
  font-weight: bold;
  letter-spacing: 3px;
  text-decoration: none;
  border: 0;

}
#header #site-name a:hover {
  color: #fff;
}

#header #site-slogan {
  text-align: right; /* JCss.Old text-align: left; */
  font-size: 12px;
  font-weight: bold;
  color: #A4BEDD;
  letter-spacing: 1px;
}

#header #logo {
  position: absolute;
  top: -8px;
  right: 20px;
}

#logo a, #logo a:visited, #logo a:hover {
  text-decoration: none;
}

#logo a img {
  border: 0;
}

/* primary links */

#primary ul {
  position: absolute;
  left: 3px; /* JCss.Old right right: 3px */
  top: 25px;
  text-align: left; /* JCss.Old text-align: right; */
  font-size: 90%;
  display: inline; /* added from shahar */
  right: 480px
  float: left;
}

#primary ul li {
  margin: 0;
  padding: 0;
  list-style-type: none;
  list-style-image: none;
  float: left; /* added from shahar */
  z-index: 2;
}

#primary ul li a, #primary ul li a:visited {
  display: block;
  margin: 0 1px 0 1px; /* JCss.Old margin: 0 1px 0 1px */
  padding: 3px .8em 0 .8em; /* JCss.Old padding: 3px .8em 0 .8em */
  color: #24375B;
  background: url(images/bg-primary.gif) repeat-x;
  height: 12px;
  border: 1px solid #96B4D5;
  border-bottom: none;
  float: left; /* this value must be unchanged from original theme ; */
  line-height: 10px;
  font-size: 10px;
}

#primary ul li a:hover {
  color: #465775;
  border-color: #A0BBDB;
  background: url(images/bg-primary-hover.gif) repeat-x;
}

/* secondary links */

#secondary ul {
  position: absolute;
  left: 4px; /* JCss.Old right right: 4px */
  top: 44px;
  text-align: left; /* JCss.Old text-align: right; */
  padding: 3px 5px 1px 5px; /* JCss.Old padding: 3px 5px 1px 5px */
  background: url(images/bg-secondary.gif) repeat-x;
  border-bottom: 1px solid #B7CFE9;
  height: 12px;
  float : left
}

#secondary ul li {
  margin: 0;
  padding: 0;
  list-style-type: none;
  list-style-image: none;
  float: left; /* my override JCss.Old float: left; */
  color: #F8FEFF;
  line-height: 1em;
}

#secondary ul li a, #secondary ul li a:visited {
  display: block;
  margin: 0 .5em 0 .5em; /* JCss.Old margin: 0 .5em 0 .5em */
  padding: 0;
  color: #DBE7F4;
  float: left; /* my override JCss.Old float: left; */
  font-size: 90%;
}

#secondary ul li a:hover {
  color: #fff;
  text-decoration: none;
  border: 0;
}

/* sidebars, regions */

.sidebar {
  text-align: right; /* JCss.Old text-align: left; */
}

.sidebar .block {
  margin-bottom: 1.5em;
}

.sidebar .block h2 {
  background-color: #E5ECF5;
  font-size: 13px;
  font-weight: bold;
  border-top: 2px solid #D1DBEC;
  margin: 10px -8px 8px -8px; /* JCss.Old margin: 10px -8px 8px -8px */
  padding: 4px 6px 4px 2px; /* JCss.Old padding: 4px 2px 4px 6px */
  color: #6C7A8D;
}

.sidebar .block h3, .sidebar .block div.title {
  font-size: 12px;
  color: #6C7A8D;
  font-weight: bold;
}

#header-region {
  position: absolute;
  top: 10px;
  right: 122px; /* JCss.Old left JCSS_TMP_VALUE: 122px */
  height: 28px;
  line-height: 28px;
  vertical-align: bottom;
  padding: 0;
  color: #F1F5F9;
}

#header-region * {
  display: inline;
  vertical-align: bottom;
}

#header-region h2, #header-region h3, #header-region div, #header-region ul, #header-region li {
  display: inline;
  padding-left: .5em; /* JCss.Old right right: .5em */
  line-height: 20px;
  font-size: 10px;
}

#header-region h2, #header-region h3 {
  font-weight: bold;
}

#header-region h2 {
  font-size: 13px;
}

#header-region input, #header-region select {
  background-color: #B4D1F1 !important;
  border-color: #8EACCE !important;
  color: #476281 !important;
}


/* footer */

#footer {
  text-align: center;
  vertical-align: middle;
  line-height: 37px;
  height: 37px;
  background: url(images/bg-footer.gif) repeat-x;
  margin: 0 0 10px 0; /* JCss.Old margin: 0 0 10px 0 */
}

/***********************
*   styling
***********************/

/* tabs */

ul.primary {
  text-align: left; /* JCss.Old text-align: right; */
  border-bottom: 1px solid #DADCE0;
}

ul.primary li a {
  background: #EBEFF7;
  border-color: #CFD5E3;
}

ul.primary li a.active {
  border-color: #CFD5E3;
  border-bottom: 0;
}

ul.primary li a:hover {
  background-color: #FBFCFE;
  border-color: #BABFC6;
}

ul.secondary {
  padding: 0;
}
ul.secondary li {
  margin: 0;
}
ul.secondary li.active a, ul.secondary li a:hover {
  border-bottom: 3px solid #BABFC6;
}

/* tables */

table {
  margin: 0.5em 0 1em 0; /* JCss.Old margin: 0.5em 0 1em 0 */
  width: 100%;
}

thead th {
  border-bottom: 2px solid #AAB5C3;
  color: #678;
  font-size: 90%;
  font-weight: bold;
  background: url(images/bg-thead.gif) repeat-x bottom left;
  padding: 4px 5px 0 5px; /* JCss.Old padding: 4px 5px 0 5px */
}

tr.even, tr.odd {
  border-color: #DADCE0;
}

tr.even {
  background-color: #fbfcfe;
}

tr.odd {
  background-color: #fff;
}

td.active {
  background: #e4ecf5;
}

td {
  padding: 3px;
}

td.menu-disabled {
  background-color: #E5E5E5;
}

/* forms */

form {
  margin-bottom: .5em;
}

input, textarea, select, textfield {
  font: 11px/160% "Verdana", sans-serif;
  color: #555;
  padding: 1px 3px 1px 3px; /* JCss.Old padding: 1px 3px 1px 3px */
}

fieldset {
  border: solid #DADCE0 1px;
  background-color: #F8F9FA;
  margin: 1em 0 1em 0; /* JCss.Old margin: 1em 0 1em 0 */
}

fieldset.collapsed {
  background-color: transparent;
  padding: 0;
}

.form-item input.error, .form-item textarea.error {
  font: 11px/100% "Verdana", sans-serif;
  border: 1px dashed #E1471D;
  color: #555;
}

#node-form, #node-form .node-form {
  overflow:auto;
}

#search  {
  margin: 5px -8px 5px -8px; /* JCss.Old margin: 5px -8px 5px -8px */
  background: url(images/crystal-search-rtl.gif) right bottom no-repeat;
  border-bottom: 2px solid #D1DBEC;
  padding: 3px 26px 0 3px; /* JCss.Old padding: 3px 3px 0 26px */
  vertical-align: bottom;
  height: 22px;
}

#search .form-item {
  display: inline;
  padding: 0;
  margin: 0;
}

#search input.form-text, #user-login-form input.form-text  {
  height: 18px;
  width: 95px;
  padding: 2px 3px 0 3px; /* JCss.Old padding: 2px 3px 0 3px */
  border: 2px solid #D1DBEC;
  border-bottom: 0;
  text-align: left; /* JCss.Old text-align: right; */
  font-family: Arial, Helvetica, sans-serif;
  color: #9CA6B4;
  background-color: #FBFCFE;
  vertical-align: bottom;
}

#search input.form-submit, #user-login-form input.form-submit  {
  width: 49px;
  margin: 0;
  height: 22px;
  padding: 0 2px 0 2px; /* JCss.Old padding: 0 2px 0 2px */
  border: 2px solid #D1DBEC;
  border-bottom: none;
  vertical-align: bottom;
  background-color: #FBFCFE;
  font-family: Arial, Helvetica, sans-serif;
  font-weight: bold;
  color: #6C7A8D;
}

#user-login-form {
  text-align: right; /* JCss.Old text-align: left; */
}

#user-login-form .form-item {
  margin: 0 0 .5em 0; /* JCss.Old margin: 0 0 .5em 0 */
}

#user-login-form .item-list {
  margin-top: .5em;
  font-size: 90%;
}

#user-login-form input.form-text {
  border: 1px solid #D1DBEC;
  text-align: right; /* JCss.Old text-align: left; */
}

#user-login-form input.form-submit {
  border: 1px solid #D1DBEC;
}

#user-login-form label {
  font-size: 90%;
  font-weight: normal;
}

#user-login-form .form-required {
  display: none;
}

#search input.form-submit:hover, #search input.form-submit:focus,
#search input.form-text:hover, #search input.form-text:focus,
#user-login-form input.form-text:hover, #user-login-form input.form-text:focus,
#user-login-form input.form-submit:hover, #user-login-form input.form-submit:focus {
  background-color: #fff;
  color: #485F7E;
  border-color: #B7C7E2;
}

/* add icons to user listing blocks */

#block-user-2 ul li, #block-user-3 ul li {
  list-style-type:none;
  list-style-image: none;
  margin-right: -5px; /* JCss.Old left JCSS_TMP_VALUE: -5px */
  padding-right: 18px; /* JCss.Old left JCSS_TMP_VALUE: 18px */
  background-image: url(images/mini-user-light-blue.png);
  background-repeat: no-repeat;
  background-position: right center;
}

/* progress bar */

.progress .bar {
  background: #fff url(images/progressbar.gif) repeat;
  border: 1px solid #00375a;
}

/* messages */

.messages {
  min-height: 32px;                 /* icon height */
  padding: 1.3em 52px .3em 1em; /* JCss.Old padding: 1.3em 1em .3em 52px */
  border: 2px solid #DADCE0;
  background: #fbfcfe;
  margin: 10px 0;
}

.messages ul {
  padding: 0 20px 0 0; /* JCss.Old padding: 0 0 0 20px */
  margin: 0;
}

div.status {
  background: url(images/icon-info.png) .5em 50% no-repeat;
}

div.error {
  border: 2px solid #E1471D;
  background: #FCD295 url(images/icon-alert.png) .5em 50% no-repeat;
}

div.error ul li, div.status ul li {
  list-style-type: square;
  list-style-image: none;
}

/* mixed elements */

div.meta, .description, .breadcrumb, .submitted, .taxonomy {
  font-size: 92%;
  color: #494949;
  line-height: 1.6em;
}


pre {
  background: #fbfcfe;
  border: 1px solid #DADCE0;
  padding: 0.75em 1.5em;
}

blockquote {
  border: 1px #DADCE0 solid;
  margin: 0.5em 1em;
  padding: 0.3em;
  font-style: italic;
}

code {
  font-size: 1em;
  font-family: Profont, 'lucida console', 'Courier New', Monaco, monospace;
}

.blockinner {
  padding: 0;
  margin: 0;
}

.preview .node, .preview .comment {
  border: 1px solid #BABFC6;
  padding: 10px;
  margin: 5px 0 10px 0; /* JCss.Old margin: 5px 0 10px 0 */
  background-color: #FAF4E1;
}

#mission {
  padding: 15px;
  margin: 0 0 10px 0; /* JCss.Old margin: 0 0 10px 0 */
  border: 2px solid #96ADC8;
  background: #BCD1EA url(images/bg-mission.gif) repeat-x bottom left;
}

.new {
  float: left; /* JCss.Old float: right; */
  color: red;
  vertical-align: super;
  font-size: 80%;
  font-weight: bold;
}

/* admin panel */

div.admin-panel {
  border: 1px solid #DADCE0;
  background-color: #fbfcfe;
  margin: 0;
  padding: 0;
  padding-bottom: 15px;
  margin-top: 15px;
}

div.admin-panel h3 {
  padding: 5px 30px 5px 5px; /* JCss.Old padding: 5px 5px 5px 30px */
  margin: 0 0 5px 0; /* JCss.Old margin: 0 0 5px 0 */
  border-bottom: 2px solid #DADCE0;
  background: #E6EAF2 url(images/crystal-run.gif) no-repeat 2px 2px;
}

/* node links */

div.links {
    text-align: left; /* JCss.Old text-align: right; */
}

ul.links {
  text-align: left; /* JCss.Old text-align: right; */
}

ul.links li.first {
  padding-right: 0px; /* JCss.Old left JCSS_TMP_VALUE: 0px */
}

.node div.links {
  padding-top: 1px;
  padding-bottom: 2px;
  border-bottom: dashed #DADCE0 1px;
}

.sticky div.links {
  border-bottom: none;
}

.comment .links {
  font-size: 90%;
}

li.comment_add a, li.comment_comments a {
  /* background: url(images/mini-comment.png) no-repeat 0 2px; */
  padding-right: 15px; /* JCss.Old left JCSS_TMP_VALUE: 15px */
}

li.node_read_more a {
  /* background: url(images/mini-readmore.png) no-repeat 0 2px; */
  padding-right: 15px; /* JCss.Old left JCSS_TMP_VALUE: 15px */
}

li.upload_attachments a {
  /* background: url(images/mini-attachment.png) no-repeat 0 2px; */
  padding-right: 15px; /* JCss.Old left JCSS_TMP_VALUE: 15px */
}

li.comment_delete a {
  /* background: url(images/mini-trash.png) no-repeat 0 0; */
  padding-right: 15px; /* JCss.Old left JCSS_TMP_VALUE: 15px */
}

li.comment_edit a {
  /* background: url(images/mini-edit.png) no-repeat 0 0; */
  padding-right: 15px; /* JCss.Old left JCSS_TMP_VALUE: 15px */
}

li.comment_reply a {
  /* background: url(images/mini-comment.png) no-repeat 0 0; */
  padding-right: 15px; /* JCss.Old left JCSS_TMP_VALUE: 15px */
}

/* node, content styles */

.node {
  margin-bottom:15px;
  padding-bottom:15px;
}

.node h2.title a {
  color: #333;
  font-weight:normal;
  margin-bottom: 0;
}

.node h2.title a:hover {
  text-decoration: underline;
  border-bottom: 0;
  color: #345;
}

.meta, .submitted, .taxonomy {
  color: #666;
}

.meta {
  padding-bottom: 1em;
}

.node .submitted {
  text-align: right; /* JCss.Old text-align: left; */
  float: right; /* JCss.Old float: left; */
  width: 99%;
}

.node .with-taxonomy .submitted {
  width: 48%;
}

.node .taxonomy {
  text-align: left; /* JCss.Old text-align: right; */
  float: left; /* JCss.Old float: right; */
  width: 48%;
}

.taxonomy .links a {
  text-decoration:none;
  border-bottom: dotted 1px #9cf;
}

.taxonomy .links a:hover {
  border-bottom: solid 1px #9cf;
}

.taxonomy li.last {
  /* background: url(images/mini-category.png) no-repeat center right; */
  padding-right: 15px !important;
}
  
  

.sticky {
  border: 1px solid #DADCE0;
  background-color: #F7FAFF;
  padding: 8px 5px 8px 5px; /* JCss.Old padding: 8px 5px 8px 5px */
}

/* book styles */

div.node div.content .book-navigation {
  background: #eee;
  margin:0;
  padding:0;
}

div.node div.content .book-navigation ul.menu {
  border:0;
  border-top:1px solid #2763A5;
  margin:0;
  padding-bottom:10px;
}

div.node div.content .book-navigation .page-links{
  background: #C1D4EA;
  border:1px solid #2763A5;
  border-width:1px 0 1px 0;
  padding:5px;
  margin:0;
}

/* forum styles */

#forum table {
  width: 100%;
}

/* aggregator styles */

.feed-item-meta {
  font-size: 90%;
  color: #666;
  text-align: left; /* JCss.Old text-align: right; */
}

h3.feed-item-title  a {
  color: #333;
  font-weight:normal;
  margin-bottom: 0;
  font-size: 13pt;
}

h3.feed-item-title a:hover {
  text-decoration: underline;
  border-bottom: 0;
  color: #345;
}

/* poll styles */

.poll .bar {
  height: 16px;
  background-color: #D4E2F2;
}

.poll .bar .foreground {
  background: url(images/bg-poll.gif) repeat-x;
  height: 16px;
  clear: none;
  float: right; /* JCss.Old float: left; */
}

.poll .vote-form {
  text-align: center;
}

.poll .vote-form .choices {
  padding-right: 5%; /* JCss.Old left JCSS_TMP_VALUE: 5% */
  text-align: right; /* JCss.Old text-align: left; */
  display: block;
}

/* pager */

.pager {
  text-align: center;
  font-size: 90%;
}

.pager a, .pager a:visited  {
  padding: 2px 3px 2px 3px; /* JCss.Old padding: 2px 3px 2px 3px */
  margin-right: 5px; /* JCss.Old left JCSS_TMP_VALUE: 5px */
  border: 1px solid #DADCE0;
  background-color: #FFFFFF;
  color: #5294C1;
}

.pager .pager-current {
  padding: 2px 3px 2px 3px; /* JCss.Old padding: 2px 3px 2px 3px */
  margin-right: 5px; /* JCss.Old left JCSS_TMP_VALUE: 5px */
  border: 1px solid #DADCE0;
  background-color: #F7F8FA;
  color: #555;
}

.pager a:hover {
  border-color: #BABFC6;
  color: #555555;
}
