/**
* Implentation of the "One True Layout" by positioneverything.net
* see http://www.positioniseverything.net/articles/onetruelayout/
* and http://www.positioniseverything.net/articles/onetruelayout/appendix/holygrail
* for details
*/

#main-wrapper {
  float: right; /* JCss.Old float: left; */
  width: 100%;
}

#main	{
  margin: 0;
}

.withleft #main {
  margin-right: 190px; /* JCss.Old left JCSS_TMP_VALUE: 190px */
}

.withright #main {
  margin-left: 190px; /* JCss.Old right right: 190px */
}

#sidebar-left	{
  float: right; /* JCss.Old float: left; */
  margin-right: -100%; /* JCss.Old left JCSS_TMP_VALUE: -100% */
  width: 174px;
  padding: 5px 8px 20px 8px; /* JCss.Old padding: 5px 8px 20px 8px */
}
#sidebar-right	{
  float: left; /* JCss.Old float: right; */
  margin-right: -100%; /* JCss.Old left JCSS_TMP_VALUE: -100% */
  width: 174px;
  padding: 5px 8px 20px 8px; /* JCss.Old padding: 5px 8px 20px 8px */
}

#sidebar-right {
  .margin-right: -190px; /* JCss.Old left JCSS_TMP_VALUE: -190px */ /* IE7 Fix */
}

* html #sidebar-right {
  margin-right: -190px; /* JCss.Old left JCSS_TMP_VALUE: -190px */ /* IE6 Fix*/
}

#footer	{
  clear: both;
}
