/**
* bluebreeze-fixed
* ----------------
*
* fixed width version of the bluebreeze theme
*
* created by Franz Heinzmann (frando)
*
* licensed under the GPL
*/

@import "../style.css";

/* layout */

#page {
  width: 600px;
  margin: 0 auto;
}

#page.one-sidebar {
  width: 700px;
}

#page.two-sidebars {
  width: 800px;
}

#container.withleft #main {
  margin-left: 150px;
}

#container.withright #main {
  margin-right: 150px;
}

#sidebar-left, #sidebar-right {
  width: 138px;
  padding: 0 6px 0 6px;
  overflow: hidden;
}

#sidebar-right {
  .margin-left: -150px; /* IE7 Fix */
}

* html #sidebar-right {
  margin-left: -150px; /* IE6 Fix*/
}

/* basic styles */

#header {
  margin-top: 0;
  padding-top: 15px;
  background: #FCFDFF url(../images/bg-header.gif) repeat-x 0 15px;
  border-left: 1px solid #D1D9E3;
  border-right: 1px solid #D1D9E3;
}

#footer {
  margin-bottom: 0;
  padding-bottom: 15px;
  background: #FCFDFF url(../images/bg-footer.gif) repeat-x 0 0;
  border-left: 1px solid #D1D9E3;
  border-right: 1px solid #D1D9E3;
}

#container {
  background-color: #FCFDFF;
  border-left: 1px solid #D1D9E3;
  border-right: 1px solid #D1D9E3;
}

body, #page, #front, #second {
  background-color: #F5F5F5;
}

#main {
  padding-top: 20px;
}

/* primary & secondary links */

/* re-positioning the primary and secondary links, as the absolute positioning 
   used in the bluebreeze theme won't work here */

#header .menu {
  position: relative;
  overflow: visible;
  float: right;
  width: 100%;
}
#primary ul {
  position: absolute;
  top: -74px;
  left: -400px;
}

#primary ul li {
  float: right;
}


#secondary ul {
  position: absolute;
  top: -58px;
  left: -400px;
  width: auto;
  background: none;
  border: none;
}

#secondary ul li {
  float: right;
  background: url(../images/bg-secondary.gif) repeat-x;
  border-bottom: 1px solid #B7CFE9;
  padding-bottom: 2px;
  padding-top: 2px;
  line-height: 11px;
}


/* sidebars */

.sidebar .block h2 {
  background-color: #EBF0F7;
  font-size: 13px;
  font-weight: bold;
  border-top: 2px solid #D1DBEC;
  margin: 10px -6px 8px -6px;
  padding: 4px 2px 4px 6px;
  color: #6C7A8D;
}


/* more styles */

#search {
  margin-top: 15px;
} 

#search input.form-text {
  width: 60px;
}